@@ -1,4 +1,5 @@
 import csv
+import json
 from abc import ABC
 from io import StringIO
 from openpyxl import Workbook
@@ -9,7 +10,7 @@ from rest_framework.renderers import BaseRenderer
 class SpreadsheetRenderer(BaseRenderer, ABC):
     level_sep = "."
 
-    def tablize(self, data, header=None):
+    def tablize(self, data, header=None, nest_compact=False):
         """
         Convert a list of data into a table.
         If there is a header provided to tablize it will efficiently yield each
@@ -24,7 +25,7 @@ class SpreadsheetRenderer(BaseRenderer, ABC):
             # dictionaries that are each exactly one level deep).  The key for
             # each item designates the name of the column that the item will
             # fall into.
-            data = self.flatten_data(data)
+            data = self.flatten_data(data, nest_compact)
 
             # Get the set of all unique headers, and sort them (unless already provided).
             if not header:
@@ -57,21 +58,21 @@ class SpreadsheetRenderer(BaseRenderer, ABC):
             # Generator will yield nothing if there's no data and no header
             pass
 
-    def flatten_data(self, data):
+    def flatten_data(self, data, nest_compact):
         """
         Convert the given data collection to a list of dictionaries that are
         each exactly one level deep. The key for each value in the dictionaries
         designates the name of the column that the value will fall into.
         """
         for item in data:
-            flat_item = self.flatten_item(item)
+            flat_item = self.flatten_item(item, nest_compact)
             yield flat_item
 
-    def flatten_item(self, item):
+    def flatten_item(self, item, nest_compact):
         if isinstance(item, list):
-            flat_item = self.flatten_list(item)
+            flat_item = self.flatten_list(item, nest_compact)
         elif isinstance(item, dict):
-            flat_item = self.flatten_dict(item)
+            flat_item = self.flatten_dict(item, nest_compact)
         else:
             flat_item = {"": item}
 
@@ -93,22 +94,34 @@ class SpreadsheetRenderer(BaseRenderer, ABC):
             nested_item[nested_header] = val
         return nested_item
 
-    def flatten_list(self, l):
+    def flatten_list(self, l, nest_compact):
         flat_list = {}
         for index, item in enumerate(l):
-            index = str(index)
-            flat_item = self.flatten_item(item)
-            nested_item = self.nest_flat_item(flat_item, index)
-            flat_list.update(nested_item)
+            if nest_compact:
+                if isinstance(item, dict) or isinstance(item, list):
+                    flat_dict[""] = json.dumps(item)
+                else:
+                    flat_dict[""] = str(item)
+            else:
+                index = str(index)
+                flat_item = self.flatten_item(item, False)
+                nested_item = self.nest_flat_item(flat_item, index)
+                flat_list.update(nested_item)
         return flat_list
 
-    def flatten_dict(self, d):
+    def flatten_dict(self, d, nest_compact):
         flat_dict = {}
         for key, item in d.items():
-            key = str(key)
-            flat_item = self.flatten_item(item)
-            nested_item = self.nest_flat_item(flat_item, key)
-            flat_dict.update(nested_item)
+            if nest_compact:
+                if isinstance(item, dict) or isinstance(item, list):
+                    flat_dict[str(key)] = json.dumps(item)
+                else:
+                    flat_dict[str(key)] = str(item)
+            else:
+                key = str(key)
+                flat_item = self.flatten_item(item, False)
+                nested_item = self.nest_flat_item(flat_item, key)
+                flat_dict.update(nested_item)
         return flat_dict
 
 
@@ -134,8 +147,9 @@ class CSVRenderer(SpreadsheetRenderer):
             data = [data]
 
         header = renderer_context.get("spreadsheet_headers")
+        compact_columns = renderer_context.get("compact_columns")
 
-        table = self.tablize(data, header=header)
+        table = self.tablize(data, header=header, nest_compact=compact_columns)
         csv_buffer = StringIO()
         csv_writer = csv.writer(csv_buffer)
         for row in table:
@@ -167,8 +181,9 @@ class XLSXRenderer(SpreadsheetRenderer):
 
         # Take header and column_header params from view
         header = renderer_context.get("spreadsheet_headers")
+        compact_columns = renderer_context.get("compact_columns")
 
-        table = self.tablize(data, header=header)
+        table = self.tablize(data, header=header, nest_compact=compact_columns)
         wb = Workbook()
         wb.active.title = "Report Worksheet"
         for row in table:
